# Using GraphQL Queries with Custom Reports
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/using-graphql-queries-with-custom-reports#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/using-graphql-queries-with-custom-reports#prerequisites)
  * [Step 1: Navigate to the Project Directory](https://help.sap.com/docs/leanix/ea/using-graphql-queries-with-custom-reports#step-1:-navigate-to-the-project-directory)
  * [Step 2: Create a Custom Report Module](https://help.sap.com/docs/leanix/ea/using-graphql-queries-with-custom-reports#step-2:-create-a-custom-report-module)
  * [Step 3: Import GraphQLFactSheetCompletionReport into the Main Module](https://help.sap.com/docs/leanix/ea/using-graphql-queries-with-custom-reports#step-3:-import-graphqlfactsheetcompletionreport-into-the-main-module)
  * [Step 4: Start the Development Server](https://help.sap.com/docs/leanix/ea/using-graphql-queries-with-custom-reports#step-4:-start-the-development-server)
  * [Summary](https://help.sap.com/docs/leanix/ea/using-graphql-queries-with-custom-reports#summary)


Learn how to use GraphQL queries when creating custom reports.
